#ifndef ITEMS_H
#define ITEMS_H

#include <QDialog>
#include <QListWidgetItem>
#include "qemaemo5dynamichomescreenwidget.h"

namespace Ui {
    class Items;
}

class Items : public QDialog
{
    Q_OBJECT

public:
    explicit Items(QWidget *parent = 0, int place=0);
    ~Items();

private:
    Ui::Items *ui;

private slots:
    void on_qsearch_clicked();
    void on_search_textChanged(QString );
    void on_listWidget_itemClicked(QListWidgetItem* item);

protected:
    virtual void keyReleaseEvent(QKeyEvent* k);

};

#endif // ITEMS_H
